@@ -11,8 +11,8 @@ from typing import (Any, Callable, List, Mapping, NamedTuple, Optional, TextIO,
 import numpy as np
 from bson import ObjectId
 import pandas as pd
-from basic.validation import input as input_checker
-from basic.error.utils import InputDataError
+from ..validation import input as input_checker
+from ..error.utils import InputDataError
 
 
 class _MISSING_TYPE:
